===============
API Reference
===============

.. currentmodule:: mobility_report

DpMobilityReport
~~~~~~~~~~~~~~~~~~~
.. autoclass:: dp_mobility_report.dpmreport.DpMobilityReport
	:members: report, to_file
